@@ -13,7 +13,7 @@ from .pylibhackrf import pyhackrf
 def main() -> None:
     parser = argparse.ArgumentParser(
         description='python_hackrf is a Python wrapper for libhackrf and hackrf-tools.',
-        usage='python_hackrf [-h] {info, sweep, operacake} ...',
+        usage='python_hackrf [-h] {info, sweep, operacake, transfer} ...',
     )
     subparsers = parser.add_subparsers(dest='command', title='Available commands')
     subparsers.required = True
@@ -26,7 +26,7 @@ def main() -> None:
     pyhackrf_operacake_parser = subparsers.add_parser(
         'operacake', help='Configure Opera Cake antenna switch connected to HackRF.', usage='python_hackrf operacake [-h] [-d] [-o] [-m] [-a] [-b] [-f] [-t] [-w] [-l] [-g]',
     )
-    pyhackrf_operacake_parser.add_argument('-d', action='store', help='serial_number. serial number of desired HackRF', metavar='')
+    pyhackrf_operacake_parser.add_argument('-d', action='store', help='serial number of desired HackRF', metavar='')
     pyhackrf_operacake_parser.add_argument('-o', '--address', action='store', help='specify a particular Opera Cake by address. Default is 0', metavar='', default=0)
     pyhackrf_operacake_parser.add_argument('-m', '--mode', action='store', help='specify switching mode [options: manual, frequency, time]', metavar='')
     pyhackrf_operacake_parser.add_argument('-a', action='store', help='set port connected to port A0', metavar='')
@@ -117,7 +117,7 @@ def main() -> None:
                     try:
                         port, freq_min, freq_max = freq_range.split(':')
                         freq_min, freq_max = int(freq_min), int(freq_max)
-                        if port in pyhackrf.operacake_ports.keys():
+                        if port in pyhackrf.py_operacake_ports:
                             freq_ranges.extend([port, freq_min, freq_max])
                     except Exception:
                         pass
@@ -129,7 +129,7 @@ def main() -> None:
                 return
 
             if args.t is not None:
-                str_dwell_times = args.f.split(',')
+                str_dwell_times = args.t.split(',')
                 dwell_times = []
                 for dwell_time in str_dwell_times:
                     try:
@@ -142,7 +142,7 @@ def main() -> None:
                             port = dwell_split[0]
                             dwell = int(args.w)
 
-                        if port in pyhackrf.operacake_ports.keys():
+                        if port in pyhackrf.py_operacake_ports:
                             dwell_times.extend([dwell, port])
                     except Exception:
                         pass
@@ -165,19 +165,19 @@ def main() -> None:
                     except Exception:
                         pass
 
-                if port_a is None:
+                if args.a is None:
                     if port_b[0] == 'B':
                         port_a = 'A1'
                     else:
                         port_a = 'B1'
 
-                if port_b is None:
+                if args.b is None:
                     if port_a[0] == 'B':
                         port_b = 'A1'
                     else:
                         port_b = 'B1'
 
-                if port_a in pyhackrf.operacake_ports.keys() and port_b in pyhackrf.operacake_ports.keys():
+                if port_a in pyhackrf.py_operacake_ports and port_b in pyhackrf.py_operacake_ports:
                     if port_a[0] != port_b[0]:
                         pyhackrf_operacake.pyhackrf_set_operacake_ports(
                             address,
@@ -215,17 +215,17 @@ def main() -> None:
 
         pyhackrf_sweep.pyhackrf_sweep(
             frequencies=frequencies,
-            sample_rate=int(args.s) * 1e6,
-            baseband_filter_bandwidth=float(args.b) * 1e6 if args.b is not None else None,
+            sample_rate=int(float(args.s) * 1e6),
+            baseband_filter_bandwidth=int(float(args.b) * 1e6) if args.b is not None else None,
             lna_gain=int(args.l),
             vga_gain=int(args.g),
             bin_width=int(args.w),
             amp_enable=args.a,
             antenna_enable=args.p,
-            sweep_style=pyhackrf.py_sweep_style.LINEAR if args.S == 'L' else (pyhackrf.py_sweep_style.INTERLEAVED if args.S == 'I' else -1),
+            sweep_style=pyhackrf.py_sweep_style.LINEAR if args.S == 'L' else (pyhackrf.py_sweep_style.INTERLEAVED if args.S == 'I' else -1),  # type: ignore
             serial_number=args.d,
             binary_output=args.B,
-            one_shot=args.__dict__.get('1'),
+            one_shot=args.__dict__.get('1'),  # type: ignore
             num_sweeps=int(args.N) if args.N is not None else None,
             filename=args.r,
             print_to_console=True,
@@ -234,11 +234,11 @@ def main() -> None:
     elif args.command == 'transfer':
         pyhackrf_transfer.pyhackrf_transfer(
             frequency=int(args.freq_hz),
-            sample_rate=int(args.s) * 1e6,
-            baseband_filter_bandwidth=float(args.b) * 1e6 if args.b is not None else None,
+            sample_rate=int(float(args.s) * 1e6),
+            baseband_filter_bandwidth=int(float(args.b) * 1e6) if args.b is not None else None,
             i_frequency=int(args.i_freq_hz) if args.i_freq_hz is not None else None,
             lo_frequency=int(args.lo_freq_hz) if args.lo_freq_hz is not None else None,
-            image_reject=pyhackrf.py_rf_path_filter.RF_PATH_FILTER_BYPASS if args.image_reject == 'bypass' else (pyhackrf.py_rf_path_filter.RF_PATH_FILTER_LOW_PASS if args.image_reject == 'low' else (pyhackrf.py_rf_path_filter.RF_PATH_FILTER_HIGH_PASS if args.image_reject == 'high' else -1)),
+            image_reject=pyhackrf.py_rf_path_filter.RF_PATH_FILTER_BYPASS if args.image_reject == 'bypass' else (pyhackrf.py_rf_path_filter.RF_PATH_FILTER_LOW_PASS if args.image_reject == 'low' else (pyhackrf.py_rf_path_filter.RF_PATH_FILTER_HIGH_PASS if args.image_reject == 'high' else -1)),  # type: ignore
             rx_lna_gain=int(args.l),
             rx_vga_gain=int(args.g),
             tx_vga_gain=int(args.x),
